# sit-rezervo

[![PyPI](https://img.shields.io/pypi/v/sit-rezervo)](https://pypi.org/project/sit-rezervo/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sit-rezervo)

Automatic booking of [Sit Trening group classes](https://www.sit.no/trening/gruppe)